# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TriangleSetGeometryAlgorithms

.. autofunction:: TriangleSetGeometryAlgorithms

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TriangleSetGeometryAlgorithms(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, showIndicesScale=None, showPointIndices=None, tagMechanics=None, showEdgeIndices=None, drawEdges=None, drawColorEdges=None, showTriangleIndices=None, drawTriangles=None, drawColorTriangles=None, drawNormals=None, drawNormalLength=None, recomputeTrianglesOrientation=None, flipNormals=None, **kwargs):
    """
    Triangle set geometry algorithms


    :param name: object name  Default value: TriangleSetGeometryAlgorithms

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param showIndicesScale: Debug : scale for view topology indices  Default value: 0.019999999553

    :param showPointIndices: Debug : view Point indices  Default value: 0

    :param tagMechanics: Tag of the Mechanical Object  Default value: 

    :param showEdgeIndices: Debug : view Edge indices.  Default value: 0

    :param drawEdges: if true, draw the edges in the topology.  Default value: 0

    :param drawColorEdges: RGB code color used to draw edges.  Default value: [[0.4000000059604645, 1.0, 0.30000001192092896, 1.0]]

    :param showTriangleIndices: Debug : view Triangle indices  Default value: 0

    :param drawTriangles: if true, draw the triangles in the topology  Default value: 0

    :param drawColorTriangles: RGBA code color used to draw edges.  Default value: [[0.30000001192092896, 0.5, 0.800000011920929, 1.0]]

    :param drawNormals: if true, draw the triangles in the topology  Default value: 0

    :param drawNormalLength: Fiber length visualisation.  Default value: 10.0

    :param recomputeTrianglesOrientation: if true, will recompute triangles orientation according to normals.  Default value: 0

    :param flipNormals: if true, will flip normal of the first triangle used to recompute triangle orientation.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, showIndicesScale=showIndicesScale, showPointIndices=showPointIndices, tagMechanics=tagMechanics, showEdgeIndices=showEdgeIndices, drawEdges=drawEdges, drawColorEdges=drawColorEdges, showTriangleIndices=showTriangleIndices, drawTriangles=drawTriangles, drawColorTriangles=drawColorTriangles, drawNormals=drawNormals, drawNormalLength=drawNormalLength, recomputeTrianglesOrientation=recomputeTrianglesOrientation, flipNormals=flipNormals)
    return "TriangleSetGeometryAlgorithms", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshMatrixMass

.. autofunction:: MeshMatrixMass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshMatrixMass(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, separateGravity=None, rayleighMass=None, vertexMass=None, massDensity=None, totalMass=None, vertexMassInfo=None, edgeMassInfo=None, edgeMass=None, computeMassOnRest=None, showGravityCenter=None, showAxisSizeFactor=None, lumping=None, printMass=None, graph=None, **kwargs):
    """
    Define a specific mass for each particle


    :param name: object name  Default value: MeshMatrixMass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param separateGravity: add separately gravity to velocity computation  Default value: 0

    :param rayleighMass: Rayleigh damping - mass matrix coefficient  Default value: 0.0

    :param vertexMass: Specify a vector giving the mass of each vertex. 
If unspecified or wrongly set, another mass information is used.  Default value: []

    :param massDensity: Specify real and strictly positive value(s) for the mass density. 
If unspecified or wrongly set, the totalMass information is used.  Default value: []

    :param totalMass: Specify the total mass resulting from all particles. 
If unspecified or wrongly set, the default value is used: totalMass = 1.0  Default value: 1.0

    :param vertexMassInfo: internal values of the particles masses on vertices, supporting topological changes  Default value: []

    :param edgeMassInfo: internal values of the particles masses on edges, supporting topological changes  Default value: []

    :param edgeMass: values of the particles masses on edges  Default value: []

    :param computeMassOnRest: If true, the mass of every element is computed based on the rest position rather than the position  Default value: 0

    :param showGravityCenter: display the center of gravity of the system  Default value: 0

    :param showAxisSizeFactor: factor length of the axis displayed (only used for rigids)  Default value: 1.0

    :param lumping: boolean if you need to use a lumped mass matrix  Default value: 0

    :param printMass: boolean if you want to check the mass conservation  Default value: 0

    :param graph: Graph of the controlled potential  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, separateGravity=separateGravity, rayleighMass=rayleighMass, vertexMass=vertexMass, massDensity=massDensity, totalMass=totalMass, vertexMassInfo=vertexMassInfo, edgeMassInfo=edgeMassInfo, edgeMass=edgeMass, computeMassOnRest=computeMassOnRest, showGravityCenter=showGravityCenter, showAxisSizeFactor=showAxisSizeFactor, lumping=lumping, printMass=printMass, graph=graph)
    return "MeshMatrixMass", params



# -*- coding: utf-8 -*-


"""
Module ConstraintSet

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    DistanceLMConstraint

    FixedLMConstraint

    DistanceLMContactConstraint

    BilateralInteractionConstraint

    DOFBlockerLMConstraint



Content:
========

.. automodule::

    DistanceLMConstraint

    FixedLMConstraint

    DistanceLMContactConstraint

    BilateralInteractionConstraint

    DOFBlockerLMConstraint



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['DistanceLMConstraint', 'FixedLMConstraint', 'DistanceLMContactConstraint', 'BilateralInteractionConstraint', 'DOFBlockerLMConstraint']
class ConstraintSet:
    from .DistanceLMConstraint import DistanceLMConstraint
    from .FixedLMConstraint import FixedLMConstraint
    from .DistanceLMContactConstraint import DistanceLMContactConstraint
    from .BilateralInteractionConstraint import BilateralInteractionConstraint
    from .DOFBlockerLMConstraint import DOFBlockerLMConstraint



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component DistanceFromTargetMapping

.. autofunction:: DistanceFromTargetMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def DistanceFromTargetMapping(self, **kwargs):
    """
    Compute edge extensions



    """
    params = dict()
    return "DistanceFromTargetMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SurfacePressureForceField

.. autofunction:: SurfacePressureForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SurfacePressureForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, pressure=None, min=None, max=None, triangleIndices=None, quadIndices=None, pulseMode=None, pressureLowerBound=None, pressureSpeed=None, volumeConservationMode=None, useTangentStiffness=None, defaultVolume=None, mainDirection=None, drawForceScale=None, **kwargs):
    """
    SurfacePressure


    :param name: object name  Default value: SurfacePressureForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param pressure: Pressure force per unit area  Default value: 0.0

    :param min: Lower bond of the selection box  Default value: [[0.0, 0.0, 0.0]]

    :param max: Upper bond of the selection box  Default value: [[0.0, 0.0, 0.0]]

    :param triangleIndices: Indices of affected triangles  Default value: []

    :param quadIndices: Indices of affected quads  Default value: []

    :param pulseMode: Cyclic pressure application  Default value: 0

    :param pressureLowerBound: Pressure lower bound force per unit area (active in pulse mode)  Default value: 0.0

    :param pressureSpeed: Continuous pressure application in Pascal per second. Only active in pulse mode  Default value: 0.0

    :param volumeConservationMode: Pressure variation follow the inverse of the volume variation  Default value: 0

    :param useTangentStiffness: Whether (non-symmetric) stiffness matrix should be used  Default value: 1

    :param defaultVolume: Default Volume  Default value: -1.0

    :param mainDirection: Main direction for pressure application  Default value: [[0.0, 0.0, 0.0]]

    :param drawForceScale: DEBUG: scale used to render force vectors  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, pressure=pressure, min=min, max=max, triangleIndices=triangleIndices, quadIndices=quadIndices, pulseMode=pulseMode, pressureLowerBound=pressureLowerBound, pressureSpeed=pressureSpeed, volumeConservationMode=volumeConservationMode, useTangentStiffness=useTangentStiffness, defaultVolume=defaultVolume, mainDirection=mainDirection, drawForceScale=drawForceScale)
    return "SurfacePressureForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component LightManager

.. autofunction:: LightManager

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def LightManager(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, shadows=None, softShadows=None, ambient=None, debugDraw=None, **kwargs):
    """
    Manage a set of lights that can cast hard and soft shadows.Soft Shadows is done using Variance Shadow Mapping (http://developer.download.nvidia.com/SDK/10.5/direct3d/Source/VarianceShadowMapping/Doc/VarianceShadowMapping.pdf)


    :param name: object name  Default value: LightManager

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param shadows: Enable Shadow in the scene. (default=0)  Default value: 0

    :param softShadows: If Shadows enabled, Enable Variance Soft Shadow in the scene. (default=0)  Default value: 0

    :param ambient: Ambient lights contribution (Vec4f)(default=[0.0f,0.0f,0.0f,0.0f])  Default value: [[0.0, 0.0, 0.0, 1.0]]

    :param debugDraw: enable/disable drawing of lights shadow textures. (default=false)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, shadows=shadows, softShadows=softShadows, ambient=ambient, debugDraw=debugDraw)
    return "LightManager", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OBJExporter

.. autofunction:: OBJExporter

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OBJExporter(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, exportEveryNumberOfSteps=None, exportAtBegin=None, exportAtEnd=None, enable=None, **kwargs):
    """
    Export the scene under the Wavefront OBJ format.When several frames are exported the file name have the following pattern: outfile000.obj outfile001.obj.


    :param name: object name  Default value: OBJExporter

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Path or filename where to export the data.  If missing the name of the component is used.  Default value: 

    :param exportEveryNumberOfSteps: export file only at specified number of steps (0=disable, default=0)  Default value: 0

    :param exportAtBegin: export file at the initialization (default=false)  Default value: 0

    :param exportAtEnd: export file when the simulation is finished (default=false)  Default value: 0

    :param enable: Enable or disable the component. (default=true)  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, exportEveryNumberOfSteps=exportEveryNumberOfSteps, exportAtBegin=exportAtBegin, exportAtEnd=exportAtEnd, enable=enable)
    return "OBJExporter", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component LinearStrainMapping

.. autofunction:: LinearStrainMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def LinearStrainMapping(self, **kwargs):
    """
    Map strain positions as a linear combination of strains, for smoothing.



    """
    params = dict()
    return "LinearStrainMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ExtrudeEdgesAndGenerateQuads

.. autofunction:: ExtrudeEdgesAndGenerateQuads

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ExtrudeEdgesAndGenerateQuads(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, extrudeDirection=None, thicknessIn=None, thicknessOut=None, numberOfSections=None, curveVertices=None, curveEdges=None, extrudedVertices=None, extrudedEdges=None, extrudedQuads=None, **kwargs):
    """
    This engine extrudes an edge-based curve into a quad surface patch


    :param name: object name  Default value: ExtrudeEdgesAndGenerateQuads

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param extrudeDirection: Direction along which to extrude the curve  Default value: [[1.0, 0.0, 0.0]]

    :param thicknessIn: Thickness of the extruded volume in the opposite direction of the normals  Default value: 0.0

    :param thicknessOut: Thickness of the extruded volume in the direction of the normals  Default value: 1.0

    :param numberOfSections: Number of sections / steps in the extrusion  Default value: 1

    :param curveVertices: Position coordinates along the initial curve  Default value: []

    :param curveEdges: Indices of the edges of the curve to extrude  Default value: []

    :param extrudedVertices: Coordinates of the extruded vertices  Default value: []

    :param extrudedEdges: List of all edges generated during the extrusion  Default value: []

    :param extrudedQuads: List of all quads generated during the extrusion  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, extrudeDirection=extrudeDirection, thicknessIn=thicknessIn, thicknessOut=thicknessOut, numberOfSections=numberOfSections, curveVertices=curveVertices, curveEdges=curveEdges, extrudedVertices=extrudedVertices, extrudedEdges=extrudedEdges, extrudedQuads=extrudedQuads)
    return "ExtrudeEdgesAndGenerateQuads", params



# -*- coding: utf-8 -*-


"""
Module 

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    Mapping

    OdeSolver

    CollisionModel

    CollisionAlgorithm

    Mass

    Engine

    VisualModel

    ContextObject

    Loader

    ForceField

    MechanicalState

    ConfigurationSetting

    ProjectiveConstraintSet

    ConstraintSet

    TopologyObject

    Controller

    ConstraintSolver

    Legacy

    LinearSolver

    Topology

    AnimationLoop

    Miscellaneous

    BehaviorModel



Content:
========

.. autoclass:: Mapping







Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['Mapping', 'OdeSolver', 'CollisionModel', 'CollisionAlgorithm', 'Mass', 'Engine', 'VisualModel', 'ContextObject', 'Loader', 'ForceField', 'MechanicalState', 'ConfigurationSetting', 'ProjectiveConstraintSet', 'ConstraintSet', 'TopologyObject', 'Controller', 'ConstraintSolver', 'Legacy', 'LinearSolver', 'Topology', 'AnimationLoop', 'Miscellaneous', 'BehaviorModel']
from .Mapping import Mapping
from .OdeSolver import OdeSolver
from .CollisionModel import CollisionModel
from .CollisionAlgorithm import CollisionAlgorithm
from .Mass import Mass
from .Engine import Engine
from .VisualModel import VisualModel
from .ContextObject import ContextObject
from .Loader import Loader
from .ForceField import ForceField
from .MechanicalState import MechanicalState
from .ConfigurationSetting import ConfigurationSetting
from .ProjectiveConstraintSet import ProjectiveConstraintSet
from .ConstraintSet import ConstraintSet
from .TopologyObject import TopologyObject
from .Controller import Controller
from .ConstraintSolver import ConstraintSolver
from .Legacy import Legacy
from .LinearSolver import LinearSolver
from .Topology import Topology
from .AnimationLoop import AnimationLoop
from .Miscellaneous import Miscellaneous
from .BehaviorModel import BehaviorModel

class BaseFactory(Mapping, OdeSolver, CollisionModel, CollisionAlgorithm, Mass, Engine, VisualModel, ContextObject, Loader, ForceField, MechanicalState, ConfigurationSetting, ProjectiveConstraintSet, ConstraintSet, TopologyObject, Controller, ConstraintSolver, Legacy, LinearSolver, Topology, AnimationLoop, Miscellaneous, BehaviorModel):
    pass


# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CenterOfMassMulti2Mapping

.. autofunction:: CenterOfMassMulti2Mapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CenterOfMassMulti2Mapping(self, **kwargs):
    """
    Set the point to the center of mass of the DOFs it is attached to



    """
    params = dict()
    return "CenterOfMassMulti2Mapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CGLinearSolver

.. autofunction:: CGLinearSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CGLinearSolver(self, iterations=None, tolerance=None, threshold=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, warmStart=None, verbose=None, graph=None, **kwargs):
    """
    Linear system solver using the conjugate gradient iterative algorithm
NewMat linear system solver using the conjugate gradient iterative algorithm


    :param name: object name  Default value: CGLinearSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param iterations: Maximum number of iterations of the Conjugate Gradient solution  Default value: 25

    :param tolerance: Desired accuracy of the Conjugate Gradient solution (ratio of current residual norm over initial residual norm)  Default value: 1e-05

    :param threshold: Minimum value of the denominator in the conjugate Gradient solution  Default value: 1e-05

    :param warmStart: Use previous solution as initial solution  Default value: 0

    :param verbose: Dump system state at each iteration  Default value: 0

    :param graph: Graph of residuals at each iteration  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, iterations=iterations, tolerance=tolerance, threshold=threshold, warmStart=warmStart, verbose=verbose, graph=graph)
    return "CGLinearSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component NonUniformHexahedralFEMForceFieldAndMass

.. autofunction:: NonUniformHexahedralFEMForceFieldAndMass

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def NonUniformHexahedralFEMForceFieldAndMass(self, poissonRatio=None, youngModulus=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, separateGravity=None, rayleighMass=None, method=None, hexahedronInfo=None, density=None, lumpedMass=None, massMatrices=None, totalMass=None, particleMasses=None, lumpedMasses=None, recursive=None, useMBK=None, **kwargs):
    """
    Non uniform Hexahedral finite elements


    :param name: object name  Default value: NonUniformHexahedralFEMForceFieldAndMass

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param separateGravity: add separately gravity to velocity computation  Default value: 0

    :param rayleighMass: Rayleigh damping - mass matrix coefficient  Default value: 0.0

    :param method: "large" or "polar" displacements  Default value: large

    :param poissonRatio: (No help available)  Default value: 0.449999988079

    :param youngModulus: (No help available)  Default value: 5000.0

    :param hexahedronInfo: Internal hexahedron data  Default value: 

    :param density: density == volumetric mass in english (kg.m-3)  Default value: 1.0

    :param lumpedMass: Does it use lumped masses?  Default value: 0

    :param massMatrices: Mass matrices per element (M_i)  Default value: []

    :param totalMass: Total mass per element  Default value: []

    :param particleMasses: Mass per particle  Default value: []

    :param lumpedMasses: Lumped masses  Default value: []

    :param recursive: Use recursive matrix computation  Default value: 0

    :param useMBK: compute MBK and use it in addMBKdx, instead of using addDForce and addMDx.  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, separateGravity=separateGravity, rayleighMass=rayleighMass, method=method, poissonRatio=poissonRatio, youngModulus=youngModulus, hexahedronInfo=hexahedronInfo, density=density, lumpedMass=lumpedMass, massMatrices=massMatrices, totalMass=totalMass, particleMasses=particleMasses, lumpedMasses=lumpedMasses, recursive=recursive, useMBK=useMBK)
    return "NonUniformHexahedralFEMForceFieldAndMass", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Mesh2PointMechanicalMapping

.. autofunction:: Mesh2PointMechanicalMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Mesh2PointMechanicalMapping(self, **kwargs):
    """
    Mechanical mapping between a set of mesh primitives (point, edge, triangle...) and a set of points generated by Mesh2PointTopologicalMapping



    """
    params = dict()
    return "Mesh2PointMechanicalMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CompareState

.. autofunction:: CompareState

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CompareState(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, interval=None, shift=None, loop=None, scalePos=None, **kwargs):
    """
    Compare State vectors from a reference frame to the associated Mechanical State


    :param name: object name  Default value: CompareState

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param filename: output file name  Default value: 

    :param interval: time duration between inputs  Default value: 0.0

    :param shift: shift between times in the file and times when they will be read  Default value: 0.0

    :param loop: set to 'true' to re-read the file when reaching the end  Default value: 0

    :param scalePos: scale the input mechanical object  Default value: 1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, interval=interval, shift=shift, loop=loop, scalePos=scalePos)
    return "CompareState", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PartialLinearMovementConstraint

.. autofunction:: PartialLinearMovementConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PartialLinearMovementConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, endTime=None, indices=None, keyTimes=None, movements=None, showMovement=None, linearMovementBetweenNodesInIndices=None, mainIndice=None, minDepIndice=None, maxDepIndice=None, imposedDisplacmentOnMacroNodes=None, X0=None, Y0=None, Z0=None, movedDirections=None, **kwargs):
    """
    translate given particles


    :param name: object name  Default value: PartialLinearMovementConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param endTime: The constraint stops acting after the given value.
Use a negative value for infinite constraints  Default value: -1.0

    :param indices: Indices of the constrained points  Default value: [[0]]

    :param keyTimes: key times for the movements  Default value: [[0.0]]

    :param movements: movements corresponding to the key times  Default value: [[0.0, 0.0, 0.0]]

    :param showMovement: Visualization of the movement to be applied to constrained dofs.  Default value: 0

    :param linearMovementBetweenNodesInIndices: Take into account the linear movement between the constrained points  Default value: 0

    :param mainIndice: The main indice node in the list of constrained nodes, it defines how to apply the linear movement between this constrained nodes   Default value: 0

    :param minDepIndice: The indice node in the list of constrained nodes, which is imposed the minimum displacment   Default value: 0

    :param maxDepIndice: The indice node in the list of constrained nodes, which is imposed the maximum displacment   Default value: 0

    :param imposedDisplacmentOnMacroNodes: The imposed displacment on macro nodes  Default value: []

    :param X0: Size of specimen in X-direction  Default value: 0.0

    :param Y0: Size of specimen in Y-direction  Default value: 0.0

    :param Z0: Size of specimen in Z-direction  Default value: 0.0

    :param movedDirections: for each direction, 1 if moved, 0 if free  Default value: [[1, 1, 1]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, endTime=endTime, indices=indices, keyTimes=keyTimes, movements=movements, showMovement=showMovement, linearMovementBetweenNodesInIndices=linearMovementBetweenNodesInIndices, mainIndice=mainIndice, minDepIndice=minDepIndice, maxDepIndice=maxDepIndice, imposedDisplacmentOnMacroNodes=imposedDisplacmentOnMacroNodes, X0=X0, Y0=Y0, Z0=Z0, movedDirections=movedDirections)
    return "PartialLinearMovementConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshSampler

.. autofunction:: MeshSampler

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshSampler(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, number=None, position=None, edges=None, maxIter=None, outputIndices=None, outputPosition=None, **kwargs):
    """
    Select uniformly distributed points on a mesh based on Euclidean or Geodesic distance measure


    :param name: object name  Default value: MeshSampler

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param number: Sample number  Default value: 1

    :param position: Input positions.  Default value: []

    :param edges: Input edges for geodesic sampling (Euclidean distances are used if not specified).  Default value: []

    :param maxIter: Max number of Lloyd iterations.  Default value: 100

    :param outputIndices: Computed sample indices.  Default value: []

    :param outputPosition: Computed sample coordinates.  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, number=number, position=position, edges=edges, maxIter=maxIter, outputIndices=outputIndices, outputPosition=outputPosition)
    return "MeshSampler", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component LMConstraintSolver

.. autofunction:: LMConstraintSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def LMConstraintSolver(self, numIterations=None, maxError=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, constraintAcc=None, constraintVel=None, constraintPos=None, graphGSError=None, traceKineticEnergy=None, graphKineticEnergy=None, **kwargs):
    """
    A Constraint Solver working specifically with LMConstraint based components


    :param name: object name  Default value: LMConstraintSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param constraintAcc: Constraint the acceleration  Default value: 0

    :param constraintVel: Constraint the velocity  Default value: 1

    :param constraintPos: Constraint the position  Default value: 1

    :param numIterations: Number of iterations for Gauss-Seidel when solving the Constraints  Default value: 25

    :param maxError: threshold for the residue of the Gauss-Seidel algorithm  Default value: 1e-07

    :param graphGSError: Graph of residuals at each iteration  Default value: 

    :param traceKineticEnergy: Trace the evolution of the Kinetic Energy throughout the solution of the system  Default value: 0

    :param graphKineticEnergy: Graph of the kinetic energy of the system  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, constraintAcc=constraintAcc, constraintVel=constraintVel, constraintPos=constraintPos, numIterations=numIterations, maxError=maxError, graphGSError=graphGSError, traceKineticEnergy=traceKineticEnergy, graphKineticEnergy=graphKineticEnergy)
    return "LMConstraintSolver", params



from sofacomponents.lib.BaseFactory import BaseFactory


class SofaFactory(BaseFactory):
    def __init__(self, debug=False):
        self._defaults = dict()
        if debug:
            self._defaults.update({"printLog": True})



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ExtrudeSurface

.. autofunction:: ExtrudeSurface

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ExtrudeSurface(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isVisible=None, heightFactor=None, triangles=None, extrusionVertices=None, surfaceVertices=None, extrusionTriangles=None, surfaceTriangles=None, **kwargs):
    """
    This class truns on spiral any topological model


    :param name: object name  Default value: ExtrudeSurface

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isVisible: is Visible ?  Default value: 1

    :param heightFactor: Factor for the height of the extrusion (based on normal) ?  Default value: 1.0

    :param triangles: List of triangle indices  Default value: []

    :param extrusionVertices: Position coordinates of the extrusion  Default value: []

    :param surfaceVertices: Position coordinates of the surface  Default value: []

    :param extrusionTriangles: Triangles indices of the extrusion  Default value: []

    :param surfaceTriangles: Indices of the triangles of the surface to extrude  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isVisible=isVisible, heightFactor=heightFactor, triangles=triangles, extrusionVertices=extrusionVertices, surfaceVertices=surfaceVertices, extrusionTriangles=extrusionTriangles, surfaceTriangles=surfaceTriangles)
    return "ExtrudeSurface", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TopologyGaussPointSampler

.. autofunction:: TopologyGaussPointSampler

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TopologyGaussPointSampler(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, method=None, position=None, transforms=None, order=None, volume=None, showSamplesScale=None, drawMode=None, showIndicesScale=None, inPosition=None, cell=None, indices=None, orientation=None, useLocalOrientation=None, fineVolumes=None, **kwargs):
    """
    Samples an object represented by a mesh


    :param name: object name  Default value: TopologyGaussPointSampler

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param method: quadrature method  Default value: 0 - Gauss-Legendre

    :param position: output sample positions  Default value: []

    :param transforms: output sample orientations  Default value: []

    :param order: order of quadrature method  Default value: 1

    :param volume: output weighted volume  Default value: []

    :param showSamplesScale: show samples scale  Default value: 0.0

    :param drawMode: 0: Green points; 1: Green spheres  Default value: 0

    :param showIndicesScale: show indices scale  Default value: 0.0

    :param inPosition: input node positions  Default value: []

    :param cell: cell index associated with each sample  Default value: []

    :param indices: list of cells where sampling is performed (all by default)  Default value: []

    :param orientation: input orientation (Euler angles) inside each cell  Default value: []

    :param useLocalOrientation: tells if orientations are defined in the local basis on each cell  Default value: 0

    :param fineVolumes: input cell volumes (typically computed from a fine model)  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, method=method, position=position, transforms=transforms, order=order, volume=volume, showSamplesScale=showSamplesScale, drawMode=drawMode, showIndicesScale=showIndicesScale, inPosition=inPosition, cell=cell, indices=indices, orientation=orientation, useLocalOrientation=useLocalOrientation, fineVolumes=fineVolumes)
    return "TopologyGaussPointSampler", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglViewport

.. autofunction:: OglViewport

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglViewport(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, screenPosition=None, screenSize=None, cameraPosition=None, cameraOrientation=None, cameraRigid=None, zNear=None, zFar=None, fovy=None, enabled=None, advancedRendering=None, useFBO=None, swapMainView=None, drawCamera=None, **kwargs):
    """
    OglViewport


    :param name: object name  Default value: OglViewport

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param screenPosition: Viewport position  Default value: [[0, 0]]

    :param screenSize: Viewport size  Default value: [[0, 0]]

    :param cameraPosition: Camera's position in eye's space  Default value: [[0.0, 0.0, 0.0]]

    :param cameraOrientation: Camera's orientation  Default value: [[0.0, 0.0, 0.0, 1.0]]

    :param cameraRigid: Camera's rigid coord  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0]]

    :param zNear: Camera's ZNear  Default value: 0.0

    :param zFar: Camera's ZFar  Default value: 0.0

    :param fovy: Field of View (Y axis)  Default value: 60.0

    :param enabled: Enable visibility of the viewport  Default value: 1

    :param advancedRendering: If true, viewport will be hidden if advancedRendering visual flag is not enabled  Default value: 0

    :param useFBO: Use a FBO to render the viewport  Default value: 1

    :param swapMainView: Swap this viewport with the main view  Default value: 0

    :param drawCamera: Draw a frame representing the camera (see it in main viewport)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, screenPosition=screenPosition, screenSize=screenSize, cameraPosition=cameraPosition, cameraOrientation=cameraOrientation, cameraRigid=cameraRigid, zNear=zNear, zFar=zFar, fovy=fovy, enabled=enabled, advancedRendering=advancedRendering, useFBO=useFBO, swapMainView=swapMainView, drawCamera=drawCamera)
    return "OglViewport", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component RandomPointDistributionInSurface

.. autofunction:: RandomPointDistributionInSurface

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def RandomPointDistributionInSurface(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, randomSeed=None, isVisible=None, drawOutputPoints=None, minDistanceBetweenPoints=None, numberOfInPoints=None, numberOfTests=None, vertices=None, triangles=None, inPoints=None, outPoints=None, **kwargs):
    """
    This class truns on spiral any topological model


    :param name: object name  Default value: RandomPointDistributionInSurface

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param randomSeed: Set a specified seed for random generation (0 for "true pseudo-randomness"   Default value: 0

    :param isVisible: is Visible ?  Default value: 1

    :param drawOutputPoints: Output points visible ?  Default value: 0

    :param minDistanceBetweenPoints: Min Distance between 2 points (-1 for true randomness)  Default value: 0.1

    :param numberOfInPoints: Number of points inside  Default value: 10

    :param numberOfTests: Number of tests to find if the point is inside or not (odd number)  Default value: 5

    :param vertices: Vertices  Default value: []

    :param triangles: Triangles indices  Default value: []

    :param inPoints: Points inside the surface  Default value: []

    :param outPoints: Points outside the surface  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, randomSeed=randomSeed, isVisible=isVisible, drawOutputPoints=drawOutputPoints, minDistanceBetweenPoints=minDistanceBetweenPoints, numberOfInPoints=numberOfInPoints, numberOfTests=numberOfTests, vertices=vertices, triangles=triangles, inPoints=inPoints, outPoints=outPoints)
    return "RandomPointDistributionInSurface", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TopologyVisualisation

.. autofunction:: TopologyVisualisation

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TopologyVisualisation(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, computeDisplay=None, positions=None, edges=None, triangles=None, tetrahedra=None, numberOfZone=None, drawZones=None, zoneSizes=None, zones=None, numberOfSurfaceZone=None, drawSurfaceZones=None, wireFrame=None, surfaceZoneSizes=None, surfaceZones=None, FiberLength=None, drawFibers=None, nodeFibers=None, drawTetraFibers=None, facetFibers=None, drawTetraBFibers=None, facetBFibers=None, **kwargs):
    """
    Tetrahedron set geometry visualisation


    :param name: object name  Default value: TopologyVisualisation

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param computeDisplay: Debug : recompute display lists.   Default value: 0

    :param positions: Data to handle topology on points  Default value: []

    :param edges: Data to handle topology on points  Default value: []

    :param triangles: Data to handle topology on points  Default value: []

    :param tetrahedra: Data to handle topology on points  Default value: []

    :param numberOfZone: Vertices of the mesh loaded  Default value: 0

    :param drawZones: Debug : allow visualisations for Mesh zones.   Default value: 0

    :param zoneSizes: See zones Size.  Default value: []

    :param zones: See zones Name.  Default value: []

    :param numberOfSurfaceZone: Vertices of the mesh loaded  Default value: 0

    :param drawSurfaceZones: Debug : allow visualisations for Mesh surface zones.   Default value: 0

    :param wireFrame: Debug : allow visualisations for Mesh surface zones in wire frame.   Default value: 0

    :param surfaceZoneSizes: See surface zones Size.  Default value: []

    :param surfaceZones: See surface zones Name.  Default value: []

    :param FiberLength: Debug : Fiber length visualisation.   Default value: 10.0

    :param drawFibers: Debug : Fiber visualisation.   Default value: 0

    :param nodeFibers: Fiber par node of the mesh loaded.  Default value: []

    :param drawTetraFibers: Debug : Tetra Fiber visualisation.   Default value: 0

    :param facetFibers: Fiber par facet of the mesh loaded.  Default value: []

    :param drawTetraBFibers: Debug : Tetra barycentrique Fiber visualisation.   Default value: 0

    :param facetBFibers: Fiber par facet of the mesh loaded, described in barycentric coordinates.  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, computeDisplay=computeDisplay, positions=positions, edges=edges, triangles=triangles, tetrahedra=tetrahedra, numberOfZone=numberOfZone, drawZones=drawZones, zoneSizes=zoneSizes, zones=zones, numberOfSurfaceZone=numberOfSurfaceZone, drawSurfaceZones=drawSurfaceZones, wireFrame=wireFrame, surfaceZoneSizes=surfaceZoneSizes, surfaceZones=surfaceZones, FiberLength=FiberLength, drawFibers=drawFibers, nodeFibers=nodeFibers, drawTetraFibers=drawTetraFibers, facetFibers=facetFibers, drawTetraBFibers=drawTetraBFibers, facetBFibers=facetBFibers)
    return "TopologyVisualisation", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TetrahedronCollisionModel

.. autofunction:: TetrahedronCollisionModel

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TetrahedronCollisionModel(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, active=None, moving=None, simulated=None, selfCollision=None, proximity=None, contactStiffness=None, contactFriction=None, contactRestitution=None, contactResponse=None, color=None, group=None, **kwargs):
    """
    collision model using a tetrahedral mesh, as described in BaseMeshTopology


    :param name: object name  Default value: TetrahedronCollisionModel

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param active: flag indicating if this collision model is active and should be included in default collision detections  Default value: 1

    :param moving: flag indicating if this object is changing position between iterations  Default value: 1

    :param simulated: flag indicating if this object is controlled by a simulation  Default value: 1

    :param selfCollision: flag indication if the object can self collide  Default value: 0

    :param proximity: Distance to the actual (visual) surface  Default value: 0.0

    :param contactStiffness: Contact stiffness  Default value: 10.0

    :param contactFriction: Contact friction coefficient (dry or viscous or unused depending on the contact method)  Default value: 0.0

    :param contactRestitution: Contact coefficient of restitution  Default value: 0.0

    :param contactResponse: if set, indicate to the ContactManager that this model should use the given class of contacts.
Note that this is only indicative, and in particular if both collision models specify a different class it is up to the manager to choose.  Default value: 

    :param color: color used to display the collision model if requested  Default value: [[1.0, 0.0, 0.0, 1.0]]

    :param group: IDs of the groups containing this model. No collision can occur between collision models included in a common group (e.g. allowing the same object to have multiple collision models)  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, active=active, moving=moving, simulated=simulated, selfCollision=selfCollision, proximity=proximity, contactStiffness=contactStiffness, contactFriction=contactFriction, contactRestitution=contactRestitution, contactResponse=contactResponse, color=color, group=group)
    return "TetrahedronCollisionModel", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component RestShapeSpringsForceField

.. autofunction:: RestShapeSpringsForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def RestShapeSpringsForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, points=None, stiffness=None, angularStiffness=None, pivot_points=None, external_points=None, recompute_indices=None, drawSpring=None, springColor=None, **kwargs):
    """
    Elastic springs generating forces on degrees of freedom between their current and rest shape position
Spring attached to rest position
Spring attached to rest position


    :param name: object name  Default value: RestShapeSpringsForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param points: points controlled by the rest shape springs  Default value: []

    :param stiffness: stiffness values between the actual position and the rest shape position  Default value: []

    :param angularStiffness: angularStiffness assigned when controlling the rotation of the points  Default value: []

    :param pivot_points: global pivot points used when translations instead of the rigid mass centers  Default value: []

    :param external_points: points from the external Mechancial State that define the rest shape springs  Default value: []

    :param recompute_indices: Recompute indices (should be false for BBOX)  Default value: 1

    :param drawSpring: draw Spring  Default value: 0

    :param springColor: spring color. (default=[0.0,1.0,0.0,1.0])  Default value: [[0.0, 1.0, 0.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, points=points, stiffness=stiffness, angularStiffness=angularStiffness, pivot_points=pivot_points, external_points=external_points, recompute_indices=recompute_indices, drawSpring=drawSpring, springColor=springColor)
    return "RestShapeSpringsForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ProjectToLineConstraint

.. autofunction:: ProjectToLineConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ProjectToLineConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, endTime=None, indices=None, drawSize=None, origin=None, direction=None, **kwargs):
    """
    Attach given particles to their initial positions


    :param name: object name  Default value: ProjectToLineConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param endTime: The constraint stops acting after the given value.
Use a negative value for infinite constraints  Default value: -1.0

    :param indices: Indices of the fixed points  Default value: [[0]]

    :param drawSize: 0 -> point based rendering, >0 -> radius of spheres  Default value: 0.0

    :param origin: A point in the line  Default value: [[0.0, 0.0, 0.0]]

    :param direction: Direction of the line  Default value: [[0.0, 0.0, 0.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, endTime=endTime, indices=indices, drawSize=drawSize, origin=origin, direction=direction)
    return "ProjectToLineConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshROI

.. autofunction:: MeshROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, edges=None, triangles=None, tetrahedra=None, ROIposition=None, ROIedges=None, ROItriangles=None, computeEdges=None, computeTriangles=None, computeTetrahedra=None, computeMeshROI=None, box=None, indices=None, edgeIndices=None, triangleIndices=None, tetrahedronIndices=None, pointsInROI=None, edgesInROI=None, trianglesInROI=None, tetrahedraInROI=None, pointsOutROI=None, edgesOutROI=None, trianglesOutROI=None, tetrahedraOutROI=None, indicesOut=None, edgeOutIndices=None, triangleOutIndices=None, tetrahedronOutIndices=None, drawOut=None, drawMesh=None, drawBox=None, drawPoints=None, drawEdges=None, drawTriangles=None, drawTetrahedra=None, drawSize=None, doUpdate=None, **kwargs):
    """
    Find the primitives (vertex/edge/triangle/tetrahedron) inside a given mesh


    :param name: object name  Default value: MeshROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position: Rest position coordinates of the degrees of freedom  Default value: []

    :param edges: Edge Topology  Default value: []

    :param triangles: Triangle Topology  Default value: []

    :param tetrahedra: Tetrahedron Topology  Default value: []

    :param ROIposition: ROI position coordinates of the degrees of freedom  Default value: []

    :param ROIedges: ROI Edge Topology  Default value: []

    :param ROItriangles: ROI Triangle Topology  Default value: []

    :param computeEdges: If true, will compute edge list and index list inside the ROI.  Default value: 1

    :param computeTriangles: If true, will compute triangle list and index list inside the ROI.  Default value: 1

    :param computeTetrahedra: If true, will compute tetrahedra list and index list inside the ROI.  Default value: 1

    :param computeMeshROI: Compute with the mesh (not only bounding box)  Default value: 1

    :param box: Bounding box defined by xmin,ymin,zmin, xmax,ymax,zmax  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param indices: Indices of the points contained in the ROI  Default value: [[0]]

    :param edgeIndices: Indices of the edges contained in the ROI  Default value: []

    :param triangleIndices: Indices of the triangles contained in the ROI  Default value: []

    :param tetrahedronIndices: Indices of the tetrahedra contained in the ROI  Default value: []

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param edgesInROI: Edges contained in the ROI  Default value: []

    :param trianglesInROI: Triangles contained in the ROI  Default value: []

    :param tetrahedraInROI: Tetrahedra contained in the ROI  Default value: []

    :param pointsOutROI: Points not contained in the ROI  Default value: []

    :param edgesOutROI: Edges not contained in the ROI  Default value: []

    :param trianglesOutROI: Triangles not contained in the ROI  Default value: []

    :param tetrahedraOutROI: Tetrahedra not contained in the ROI  Default value: []

    :param indicesOut: Indices of the points not contained in the ROI  Default value: []

    :param edgeOutIndices: Indices of the edges not contained in the ROI  Default value: []

    :param triangleOutIndices: Indices of the triangles not contained in the ROI  Default value: []

    :param tetrahedronOutIndices: Indices of the tetrahedra not contained in the ROI  Default value: []

    :param drawOut: Draw the data not contained in the ROI  Default value: 0

    :param drawMesh: Draw Mesh used for the ROI  Default value: 0

    :param drawBox: Draw the Bounding box around the mesh used for the ROI  Default value: 0

    :param drawPoints: Draw Points  Default value: 0

    :param drawEdges: Draw Edges  Default value: 0

    :param drawTriangles: Draw Triangles  Default value: 0

    :param drawTetrahedra: Draw Tetrahedra  Default value: 0

    :param drawSize: rendering size for mesh and topological elements  Default value: 0.0

    :param doUpdate: Update the computation (not only at the init)  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, edges=edges, triangles=triangles, tetrahedra=tetrahedra, ROIposition=ROIposition, ROIedges=ROIedges, ROItriangles=ROItriangles, computeEdges=computeEdges, computeTriangles=computeTriangles, computeTetrahedra=computeTetrahedra, computeMeshROI=computeMeshROI, box=box, indices=indices, edgeIndices=edgeIndices, triangleIndices=triangleIndices, tetrahedronIndices=tetrahedronIndices, pointsInROI=pointsInROI, edgesInROI=edgesInROI, trianglesInROI=trianglesInROI, tetrahedraInROI=tetrahedraInROI, pointsOutROI=pointsOutROI, edgesOutROI=edgesOutROI, trianglesOutROI=trianglesOutROI, tetrahedraOutROI=tetrahedraOutROI, indicesOut=indicesOut, edgeOutIndices=edgeOutIndices, triangleOutIndices=triangleOutIndices, tetrahedronOutIndices=tetrahedronOutIndices, drawOut=drawOut, drawMesh=drawMesh, drawBox=drawBox, drawPoints=drawPoints, drawEdges=drawEdges, drawTriangles=drawTriangles, drawTetrahedra=drawTetrahedra, drawSize=drawSize, doUpdate=doUpdate)
    return "MeshROI", params



"""
A sofa scene to autogenerate the python wrapping function from the runtime informations.

"""

# -*- coding: utf-8 -*-
import os
import sys

import Sofa

# from sphinx import make_mode
reserved = ["in", "with", "for", "if", "def", "class", "global"]


def kv2params(kw):
    p = ""
    req = []
    opt = []
    for k in kw:
        if k.name in reserved:
            print("Warning: this is an invalid arguments as it is a python keyword")
            continue

        if k.name.find(" ") != -1:
            print("Warning: this is an invalid arguments name: " + repr(k.name))
            continue

        if len(k.name) != 0:
            if k.isRequired():
                req.append(k)
            else:
                opt.append(k)

    for k in req:
        p += ", " + k.name + "=None"

    for k in opt:
        # p += ", " + k.name + "=" + repr(k.value)
        p += ", " + k.name + "=None"

    return p


def kv2call(kw):
    p = ""
    for k in kw:
        if k.name in reserved:
            continue

        if k.name.find(" ") != -1:
            continue

        if len(k.name) != 0:
            p += k.name + "=" + str(k.name) + ", "
    if p.endswith(", "):
        p = p[:-2]
    return p


def kv2doc(kw):
    p = ""
    for k in kw:
        if len(k.name) == 0:
            continue
        if k.name.find(" ") != -1:
            continue

        if k.name in reserved:
            p += (
                "    :param "
                + k.name
                + ": "
                + str(k.getHelp())
                + " (NB: use the kwargs syntax as name is a reserved word in python)\n\n"
            )
        else:
            p += (
                "    :param "
                + k.name
                + ": "
                + str(k.getHelp())
                + "  Default value: "
                + str(k.value)
                + "\n\n"
            )

    return p


def makeInitFile(rootDir):
    entries = {}
    for dirpath, dirnames, filenames in os.walk(rootDir):
        initfile = open(dirpath + "/__init__.py", "wt")
        res_dir, res_file = [], []
        for d in dirnames:
            if d != "__pycache__":
                res_dir.append(d)
        for f in filenames:
            if f.endswith(".py") and f != "__init__.py":
                res_file.append(f[:-3])
        listc = ""
        res = res_dir + res_file
        for r in res:
            listc += "    " + str(r) + "\n\n"

        initfile.write("# -*- coding: utf-8 -*-\n\n")
        initfile.write(
            """
\"\"\"
Module %s

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

%s

Content:
========

.. automodule::

%s

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
\"\"\"
"""
            % (os.path.basename(dirpath), listc, listc)
        )
        initfile.write("# __all__=" + repr(res) + "\n")

        ind = "    "
        if os.path.basename(dirpath) == "":
            for r in res_dir:
                initfile.write("from .{0} import {0}\n".format(r))
            initfile.write("\nclass BaseFactory({}):\n{ind}pass".format(", ".join([r for r in res_dir]), ind=ind))
        else:
            initfile.write("class {}:\n".format(os.path.basename(dirpath)))
        # else:
        #     for r in res_dir:
        #         initfile.write(ind + "from . import " + str(r) + "\n")
        for r in res_file:
            initfile.write(ind + "from .{0} import {0}\n".format(str(r)))
        initfile.close()

        # print(str((dirpath, dirnames, filenames)))


def createScene(rootNode):
    sys.argv = ["./mysphinx.py", "-M", "html", "source", "build"]
    backlist = ["PythonMainScriptController"]
    rootNode.createObject("MechanicalObject")
    rootNode.createObject("RequiredPlugin", pluginName="CardiacMeshTools MechanicalHeart SofaPython")

    for (name, desc) in Sofa.getAvailableComponents():
        categories = ["Legacy"]
        args = {}
        if name not in backlist:
            try:
                print("Processing: " + name)
                obj = rootNode.createObject(name)
                # args = obj.getDataFields()
                args = obj.getListOfDataFields()
                categories = obj.getCategories()
            except Exception, e:
                print("UNable to get DOC")
                pass
        params = kv2params(args)
        params2 = kv2call(args)
        paramsmd = kv2doc(args)
        code = """

@sofa_component
def %s(self%s, **kwargs):
    \"\"\"
    %s

%s
    \"\"\"
    params = dict(%s)
    return "%s", params
""" % (
            name,
            params,
            desc,
            paramsmd,
            params2,
            name,
        )

        targetpath = "BaseFactory/"

        if not os.path.exists(targetpath):
            os.mkdir(targetpath)

        pathname = targetpath + categories[0] + "/"
        if not os.path.exists(pathname):
            os.mkdir(pathname)
        outfile = open(pathname + name + ".py", "wt")
        outfile.write("# -*- coding: utf-8 -*-\n\n")
        outfile.write(
            "from sofacomponents.lib.base_component import sofa_component\n\n"
        )
        outfile.write(
            """
\"\"\"
Component %s

.. autofunction:: %s

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
\"\"\"
"""
            % (name, name)
        )

        outfile.write(code)

    outfile.close()

    makeInitFile(targetpath)
    print("Processing DONE")
    # make_mode.run_make_mode(sys.argv[2:])
    sys.exit(-1)



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component RuleBasedContactManager

.. autofunction:: RuleBasedContactManager

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def RuleBasedContactManager(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, response=None, responseParams=None, variables=None, rules=None, **kwargs):
    """
    Create different response to the collisions based on a set of rules


    :param name: object name  Default value: RuleBasedContactManager

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param response: contact response class  Default value: default

    :param responseParams: contact response parameters (syntax: name1=value1&name2=value2&...)  Default value: 

    :param variables: Define a list of variables to be used inside the rules  Default value: 

    :param rules: Ordered list of rules, each with a triplet of strings.
The first two define either the name of the collision model, its group number, or * meaning any model.
The last string define the response algorithm to use for contacts matched by this rule.
Rules are applied in the order they are specified. If none match a given contact, the default response is used.
  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, response=response, responseParams=responseParams, variables=variables, rules=rules)
    return "RuleBasedContactManager", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ContractionCouplingForceField

.. autofunction:: ContractionCouplingForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ContractionCouplingForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, tetraInfo=None, tetraContractivityParam=None, depolarisationTimes=None, uniquedepolarisationTimes=None, APD=None, APDVT=None, TdVT=None, withVT=None, useVerdandi=None, n0=None, alpha=None, StarlingEffect=None, n1=None, n2=None, tagMechanics=None, useSimple=None, withFile=None, file=None, **kwargs):
    """
    Coupling for contraction on heart


    :param name: object name  Default value: ContractionCouplingForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param tetraInfo: Data to handle topology on tetrahedra  Default value: 

    :param tetraContractivityParam: <Contractivity,stiffness,contractionRate,relaxationrate> by tetra  Default value: []

    :param depolarisationTimes: depolarisationTimes at each node  Default value: []

    :param uniquedepolarisationTimes: depolarisationTimes at each node  Default value: 0.0

    :param APD: APD at each node  Default value: []

    :param APDVT: APDVT  Default value: []

    :param TdVT: TdVT  Default value: []

    :param withVT: if VT TD are used  Default value: 0

    :param useVerdandi: if used with verdandi  Default value: 0

    :param n0: reduction parameter between 0 and 1  Default value: 0.0

    :param alpha: alpha  Default value: 0.0

    :param StarlingEffect: if used with verdandi  Default value: 0

    :param n1: reduction parameter between 0 and 1  Default value: 0.0

    :param n2: reduction parameter between 0 and 1  Default value: 0.0

    :param tagMechanics: Tag of the Mechanical Object  Default value: meca

    :param useSimple: If the model should be simplified  Default value: 0

    :param withFile: if the electrophysiology is precomputed  Default value: 0

    :param file: File where to store the Monitoring  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, tetraInfo=tetraInfo, tetraContractivityParam=tetraContractivityParam, depolarisationTimes=depolarisationTimes, uniquedepolarisationTimes=uniquedepolarisationTimes, APD=APD, APDVT=APDVT, TdVT=TdVT, withVT=withVT, useVerdandi=useVerdandi, n0=n0, alpha=alpha, StarlingEffect=StarlingEffect, n1=n1, n2=n2, tagMechanics=tagMechanics, useSimple=useSimple, withFile=withFile, file=file)
    return "ContractionCouplingForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TetrahedronDiffusionFEMForceField

.. autofunction:: TetrahedronDiffusionFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TetrahedronDiffusionFEMForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, constantDiffusionCoefficient=None, tetraDiffusionCoefficient=None, scalarDiffusion=None, anisotropyRatio=None, transverseAnisotropyArray=None, tagMechanics=None, drawConduc=None, **kwargs):
    """
    Isotropic or anisotropic diffusion on Tetrahedral Meshes


    :param name: object name  Default value: TetrahedronDiffusionFEMForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param constantDiffusionCoefficient: Constant diffusion coefficient  Default value: 1.0

    :param tetraDiffusionCoefficient: Diffusion coefficient for each tetrahedron, by default equal to constantDiffusionCoefficient.  Default value: []

    :param scalarDiffusion: if true, diffuse only on the first dimension.  Default value: 0

    :param anisotropyRatio: Anisotropy ratio (r²>1).
 Default is 1.0 = isotropy.  Default value: 1.0

    :param transverseAnisotropyArray: Data to handle topology on tetrahedra  Default value: []

    :param tagMechanics: Tag of the Mechanical Object.  Default value: meca

    :param drawConduc: To display conductivity map.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, constantDiffusionCoefficient=constantDiffusionCoefficient, tetraDiffusionCoefficient=tetraDiffusionCoefficient, scalarDiffusion=scalarDiffusion, anisotropyRatio=anisotropyRatio, transverseAnisotropyArray=transverseAnisotropyArray, tagMechanics=tagMechanics, drawConduc=drawConduc)
    return "TetrahedronDiffusionFEMForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Monitor

.. autofunction:: Monitor

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Monitor(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, indices=None, ExportPositions=None, ExportVelocities=None, ExportForces=None, showPositions=None, PositionsColor=None, showVelocities=None, VelocitiesColor=None, showForces=None, ForcesColor=None, showMinThreshold=None, showTrajectories=None, TrajectoriesPrecision=None, TrajectoriesColor=None, sizeFactor=None, fileName=None, **kwargs):
    """
    Monitoring of particles
Monitoring of particles
Monitoring of particles


    :param name: object name  Default value: Monitor

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param indices: MechanicalObject points indices to monitor  Default value: []

    :param ExportPositions: export Monitored positions as gnuplot file  Default value: 0

    :param ExportVelocities: export Monitored velocities as gnuplot file  Default value: 0

    :param ExportForces: export Monitored forces as gnuplot file  Default value: 0

    :param showPositions: see the Monitored positions  Default value: 0

    :param PositionsColor: define the color of positions  Default value: [[1.0, 1.0, 0.0, 1.0]]

    :param showVelocities: see the Monitored velocities  Default value: 0

    :param VelocitiesColor: define the color of velocities  Default value: [[1.0, 1.0, 0.0, 1.0]]

    :param showForces: see the Monitored forces  Default value: 0

    :param ForcesColor: define the color of forces  Default value: [[1.0, 1.0, 0.0, 1.0]]

    :param showMinThreshold: under this value, vectors are not represented  Default value: 0.01

    :param showTrajectories: print the trajectory of Monitored particles  Default value: 0

    :param TrajectoriesPrecision: set the dt between to save of positions  Default value: 0.1

    :param TrajectoriesColor: define the color of the trajectories  Default value: [[1.0, 1.0, 0.0, 1.0]]

    :param sizeFactor: factor to multiply to arrows  Default value: 1.0

    :param fileName: name of the plot files to be generated  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, indices=indices, ExportPositions=ExportPositions, ExportVelocities=ExportVelocities, ExportForces=ExportForces, showPositions=showPositions, PositionsColor=PositionsColor, showVelocities=showVelocities, VelocitiesColor=VelocitiesColor, showForces=showForces, ForcesColor=ForcesColor, showMinThreshold=showMinThreshold, showTrajectories=showTrajectories, TrajectoriesPrecision=TrajectoriesPrecision, TrajectoriesColor=TrajectoriesColor, sizeFactor=sizeFactor, fileName=fileName)
    return "Monitor", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ConstraintAnimationLoop

.. autofunction:: ConstraintAnimationLoop

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ConstraintAnimationLoop(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, displayTime=None, tolerance=None, maxIterations=None, doCollisionsFirst=None, doubleBuffer=None, scaleTolerance=None, allVerified=None, sor=None, schemeCorrection=None, realTimeCompensation=None, graphErrors=None, graphConstraints=None, graphForces=None, **kwargs):
    """
    Constraint animation loop manager


    :param name: object name  Default value: ConstraintAnimationLoop

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param displayTime: Display time for each important step of ConstraintAnimationLoop.  Default value: 0

    :param tolerance: Tolerance of the Gauss-Seidel  Default value: 1e-05

    :param maxIterations: Maximum number of iterations of the Gauss-Seidel  Default value: 1000

    :param doCollisionsFirst: Compute the collisions first (to support penality-based contacts)  Default value: 0

    :param doubleBuffer: Buffer the constraint problem in a double buffer to be accessible with an other thread  Default value: 0

    :param scaleTolerance: Scale the error tolerance with the number of constraints  Default value: 1

    :param allVerified: All contraints must be verified (each constraint's error < tolerance)  Default value: 0

    :param sor: Successive Over Relaxation parameter (0-2)  Default value: 1.0

    :param schemeCorrection: Apply new scheme where compliance is progressively corrected  Default value: 0

    :param realTimeCompensation: If the total computational time T < dt, sleep(dt-T)  Default value: 0

    :param graphErrors: Sum of the constraints' errors at each iteration  Default value: 

    :param graphConstraints: Graph of each constraint's error at the end of the resolution  Default value: 

    :param graphForces: Graph of each constraint's force at each step of the resolution  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, displayTime=displayTime, tolerance=tolerance, maxIterations=maxIterations, doCollisionsFirst=doCollisionsFirst, doubleBuffer=doubleBuffer, scaleTolerance=scaleTolerance, allVerified=allVerified, sor=sor, schemeCorrection=schemeCorrection, realTimeCompensation=realTimeCompensation, graphErrors=graphErrors, graphConstraints=graphConstraints, graphForces=graphForces)
    return "ConstraintAnimationLoop", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component HEMLStVKForceField

.. autofunction:: HEMLStVKForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def HEMLStVKForceField(self, **kwargs):
    """
    St Venant-Kirchhoff (Hooke's Law for isotropic homogeneous materials)



    """
    params = dict()
    return "HEMLStVKForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglColorMap

.. autofunction:: OglColorMap

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglColorMap(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, paletteSize=None, colorScheme=None, showLegend=None, legendOffset=None, legendTitle=None, min=None, max=None, legendRangeScale=None, **kwargs):
    """
    Provides color palette and support for conversion of numbers to colors.


    :param name: object name  Default value: OglColorMap

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param paletteSize: How many colors to use  Default value: 256

    :param colorScheme: Color scheme to use  Default value: HSV

    :param showLegend: Activate rendering of color scale legend on the side  Default value: 0

    :param legendOffset: Draw the legend on screen with an x,y offset  Default value: [[10.0, 5.0]]

    :param legendTitle: Add a title to the legend  Default value: 

    :param min: min value for drawing the legend without the need to actually use the range with getEvaluator method wich sets the min  Default value: 0.0

    :param max: max value for drawing the legend without the need to actually use the range with getEvaluator method wich sets the max  Default value: 0.0

    :param legendRangeScale: to change the unit of the min/max value of the legend  Default value: 1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, paletteSize=paletteSize, colorScheme=colorScheme, showLegend=showLegend, legendOffset=legendOffset, legendTitle=legendTitle, min=min, max=max, legendRangeScale=legendRangeScale)
    return "OglColorMap", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GaussPointContainer

.. autofunction:: GaussPointContainer

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GaussPointContainer(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, method=None, position=None, transforms=None, order=None, volume=None, showSamplesScale=None, drawMode=None, showIndicesScale=None, volumeDim=None, inputVolume=None, **kwargs):
    """
    Container for user defined Gauss points (position and volume)


    :param name: object name  Default value: GaussPointContainer

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param method: quadrature method  Default value: 0 - Gauss-Legendre

    :param position: output sample positions  Default value: []

    :param transforms: output sample orientations  Default value: []

    :param order: order of quadrature method  Default value: 1

    :param volume: output weighted volume  Default value: []

    :param showSamplesScale: show samples scale  Default value: 0.0

    :param drawMode: 0: Green points; 1: Green spheres  Default value: 0

    :param showIndicesScale: show indices scale  Default value: 0.0

    :param volumeDim: dimension of quadrature weight vectors  Default value: 1

    :param inputVolume: weighted volumes (=quadrature weights)  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, method=method, position=position, transforms=transforms, order=order, volume=volume, showSamplesScale=showSamplesScale, drawMode=drawMode, showIndicesScale=showIndicesScale, volumeDim=volumeDim, inputVolume=inputVolume)
    return "GaussPointContainer", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PythonMainScriptController

.. autofunction:: PythonMainScriptController

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PythonMainScriptController(self, **kwargs):
    """
    A Sofa controller scripted in python, looking for callbacks directly in the file (not in a class like the more general and powerful PythonScriptController



    """
    params = dict()
    return "PythonMainScriptController", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TriangleDeformationMapping

.. autofunction:: TriangleDeformationMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TriangleDeformationMapping(self, **kwargs):
    """
    Compute deformation gradients in triangles



    """
    params = dict()
    return "TriangleDeformationMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Quad2TriangleTopologicalMapping

.. autofunction:: Quad2TriangleTopologicalMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Quad2TriangleTopologicalMapping(self, **kwargs):
    """
    Special case of mapping where QuadSetTopology is converted to TriangleSetTopology



    """
    params = dict()
    return "Quad2TriangleTopologicalMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ContractionForceField

.. autofunction:: ContractionForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ContractionForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, viscosityParameter=None, heartPeriod=None, addElastometry=None, useCoupling=None, useVerdandi=None, DesactivateElastoIfNoElec=None, tagContraction=None, tagSolver=None, elasticModulus=None, tetraPloted=None, graph=None, graph2=None, fiberDirections=None, tetraContractivityParam=None, depolarisationTimes=None, APD=None, calculateStress=None, stressFile=None, SecSPK_passive=None, tetrahedronInfo=None, edgeInfo=None, file=None, **kwargs):
    """
    Contraction Force for heart beating


    :param name: object name  Default value: ContractionForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param viscosityParameter: for passive relaxation  Default value: 0.0

    :param heartPeriod: heart Period  Default value: 0.0

    :param addElastometry: If we want the elastic component in series  Default value: 0

    :param useCoupling: if the contraction is couple  Default value: 0

    :param useVerdandi: useVerdandi  Default value: 0

    :param DesactivateElastoIfNoElec: set to 1 for calculating the cauchy stress  Default value: 0

    :param tagContraction: Tag of the contraction node  Default value: tagContraction

    :param tagSolver: Tag of the Solver Object  Default value: solver

    :param elasticModulus: modulus for the elastic component in series  Default value: 0.0

    :param tetraPloted: tetra index of values display in graph for each iteration.  Default value: 0

    :param graph: Vertex state value per iteration  Default value: 

    :param graph2: Vertex state value per iteration  Default value: 

    :param fiberDirections:  file with fibers at each tetra  Default value: []

    :param tetraContractivityParam: <Contractivity,contractionRate,relaxationrate> by tetra  Default value: []

    :param depolarisationTimes: depolarisationTimes at each node  Default value: []

    :param APD: APD at each node  Default value: []

    :param calculateStress: set to 1 for calculating the cauchy stress  Default value: 0

    :param stressFile: name of the output cauchy stress file  Default value: CauchyStress.txt

    :param SecSPK_passive: second piola kirshoff tensor of passive part  Default value: []

    :param tetrahedronInfo: Data to handle topology on tetrahedra  Default value: 

    :param edgeInfo: Data to handle topology on edges  Default value: 

    :param file: File where to store the Monitoring  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, viscosityParameter=viscosityParameter, heartPeriod=heartPeriod, addElastometry=addElastometry, useCoupling=useCoupling, useVerdandi=useVerdandi, DesactivateElastoIfNoElec=DesactivateElastoIfNoElec, tagContraction=tagContraction, tagSolver=tagSolver, elasticModulus=elasticModulus, tetraPloted=tetraPloted, graph=graph, graph2=graph2, fiberDirections=fiberDirections, tetraContractivityParam=tetraContractivityParam, depolarisationTimes=depolarisationTimes, APD=APD, calculateStress=calculateStress, stressFile=stressFile, SecSPK_passive=SecSPK_passive, tetrahedronInfo=tetrahedronInfo, edgeInfo=edgeInfo, file=file)
    return "ContractionForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component EulerImplicitSolver

.. autofunction:: EulerImplicitSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def EulerImplicitSolver(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, rayleighStiffness=None, rayleighMass=None, vdamping=None, firstOrder=None, trapezoidalScheme=None, solveConstraint=None, threadSafeVisitor=None, **kwargs):
    """
    Time integrator using implicit backward Euler scheme


    :param name: object name  Default value: EulerImplicitSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param rayleighStiffness: Rayleigh damping coefficient related to stiffness, > 0  Default value: 0.0

    :param rayleighMass: Rayleigh damping coefficient related to mass, > 0  Default value: 0.0

    :param vdamping: Velocity decay coefficient (no decay if null)  Default value: 0.0

    :param firstOrder: Use backward Euler scheme for first order ode system.  Default value: 0

    :param trapezoidalScheme: Optional: use the trapezoidal scheme instead of the implicit Euler scheme and get second order accuracy in time  Default value: 0

    :param solveConstraint: Apply ConstraintSolver (requires a ConstraintSolver in the same node as this solver, disabled by by default for now)  Default value: 0

    :param threadSafeVisitor: If true, do not use realloc and free visitors in fwdInteractionForceField.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, rayleighStiffness=rayleighStiffness, rayleighMass=rayleighMass, vdamping=vdamping, firstOrder=firstOrder, trapezoidalScheme=trapezoidalScheme, solveConstraint=solveConstraint, threadSafeVisitor=threadSafeVisitor)
    return "EulerImplicitSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component HausdorffDistance

.. autofunction:: HausdorffDistance

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def HausdorffDistance(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, points1=None, points2=None, d12=None, d21=None, max=None, update=None, **kwargs):
    """
    Compute the Hausdorff distance of two point clouds


    :param name: object name  Default value: HausdorffDistance

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param points1: Points belonging to the first point cloud  Default value: []

    :param points2: Points belonging to the second point cloud  Default value: []

    :param d12: Distance from point cloud 1 to 2  Default value: 0.0

    :param d21: Distance from point cloud 2 to 1  Default value: 0.0

    :param max: Symmetrical Hausdorff distance  Default value: 0.0

    :param update: Recompute every time step  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, points1=points1, points2=points2, d12=d12, d21=d21, max=max, update=update)
    return "HausdorffDistance", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PairBoxROI

.. autofunction:: PairBoxROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PairBoxROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, inclusiveBox=None, includedBox=None, position=None, meshPosition=None, indices=None, pointsInROI=None, drawInclusiveBox=None, drawInclusdedBx=None, drawPoints=None, drawSize=None, **kwargs):
    """
    Find the primitives (vertex/edge/triangle/tetrahedron) inside a given box


    :param name: object name  Default value: PairBoxROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param inclusiveBox: Inclusive box defined by xmin,ymin,zmin, xmax,ymax,zmax  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param includedBox: Included box defined by xmin,ymin,zmin, xmax,ymax,zmax  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param position: Rest position coordinates of the degrees of freedom  Default value: []

    :param meshPosition: Vertices of the mesh loaded  Default value: []

    :param indices: Indices of the points contained in the ROI  Default value: []

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param drawInclusiveBox: Draw Inclusive Box  Default value: 0

    :param drawInclusdedBx: Draw Included Box  Default value: 0

    :param drawPoints: Draw Points  Default value: 0

    :param drawSize: Draw Size  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, inclusiveBox=inclusiveBox, includedBox=includedBox, position=position, meshPosition=meshPosition, indices=indices, pointsInROI=pointsInROI, drawInclusiveBox=drawInclusiveBox, drawInclusdedBx=drawInclusdedBx, drawPoints=drawPoints, drawSize=drawSize)
    return "PairBoxROI", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Visual3DText

.. autofunction:: Visual3DText

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Visual3DText(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, text=None, position=None, scale=None, color=None, depthTest=None, **kwargs):
    """
    Display 3D camera-oriented text


    :param name: object name  Default value: Visual3DText

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param text: Test to display  Default value: 

    :param position: 3d position  Default value: [[0.0, 0.0, 0.0]]

    :param scale: text scale  Default value: 1.0

    :param color: text color. (default=[1.0,1.0,1.0,1.0])  Default value: [[1.0, 1.0, 1.0, 1.0]]

    :param depthTest: perform depth test  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, text=text, position=position, scale=scale, color=color, depthTest=depthTest)
    return "Visual3DText", params



# -*- coding: utf-8 -*-


"""
Module CollisionModel

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    LineCollisionModel

    TetrahedronCollisionModel

    SphereCollisionModel

    TriangleOctreeModel

    CapsuleCollisionModel

    TriangleModelInRegularGrid

    CylinderCollisionModel

    TriangleCollisionModel

    PointCollisionModel

    CubeCollisionModel

    RayCollisionModel



Content:
========

.. automodule::

    LineCollisionModel

    TetrahedronCollisionModel

    SphereCollisionModel

    TriangleOctreeModel

    CapsuleCollisionModel

    TriangleModelInRegularGrid

    CylinderCollisionModel

    TriangleCollisionModel

    PointCollisionModel

    CubeCollisionModel

    RayCollisionModel



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['LineCollisionModel', 'TetrahedronCollisionModel', 'SphereCollisionModel', 'TriangleOctreeModel', 'CapsuleCollisionModel', 'TriangleModelInRegularGrid', 'CylinderCollisionModel', 'TriangleCollisionModel', 'PointCollisionModel', 'CubeCollisionModel', 'RayCollisionModel']
class CollisionModel:
    from .LineCollisionModel import LineCollisionModel
    from .TetrahedronCollisionModel import TetrahedronCollisionModel
    from .SphereCollisionModel import SphereCollisionModel
    from .TriangleOctreeModel import TriangleOctreeModel
    from .CapsuleCollisionModel import CapsuleCollisionModel
    from .TriangleModelInRegularGrid import TriangleModelInRegularGrid
    from .CylinderCollisionModel import CylinderCollisionModel
    from .TriangleCollisionModel import TriangleCollisionModel
    from .PointCollisionModel import PointCollisionModel
    from .CubeCollisionModel import CubeCollisionModel
    from .RayCollisionModel import RayCollisionModel



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PrecomputedWarpPreconditioner

.. autofunction:: PrecomputedWarpPreconditioner

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PrecomputedWarpPreconditioner(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, jmjt_twostep=None, verbose=None, use_file=None, share_matrix=None, solverName=None, use_rotations=None, draw_rotations_scale=None, **kwargs):
    """
    Linear system solver based on a precomputed inverse matrix, wrapped by a per-node rotation matrix


    :param name: object name  Default value: PrecomputedWarpPreconditioner

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param jmjt_twostep: Use two step algorithm to compute JMinvJt  Default value: 1

    :param verbose: Dump system state at each iteration  Default value: 0

    :param use_file: Dump system matrix in a file  Default value: 1

    :param share_matrix: Share the compliance matrix in memory if they are related to the same file (WARNING: might require to reload Sofa when opening a new scene...)  Default value: 1

    :param solverName: Name of the solver to use to precompute the first matrix  Default value: 

    :param use_rotations: Use Rotations around the preconditioner  Default value: 1

    :param draw_rotations_scale: Scale rotations in draw function  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, jmjt_twostep=jmjt_twostep, verbose=verbose, use_file=use_file, share_matrix=share_matrix, solverName=solverName, use_rotations=use_rotations, draw_rotations_scale=draw_rotations_scale)
    return "PrecomputedWarpPreconditioner", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglShaderVisualModel

.. autofunction:: OglShaderVisualModel

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglShaderVisualModel(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, restPosition=None, normal=None, initRestPositions=None, useNormals=None, updateNormals=None, computeTangents=None, updateTangents=None, handleDynamicTopology=None, fixMergedUVSeams=None, keepLines=None, vertices=None, texcoords=None, tangents=None, bitangents=None, edges=None, triangles=None, quads=None, vertPosIdx=None, vertNormIdx=None, filename=None, texturename=None, translation=None, rotation=None, scale3d=None, scaleTex=None, translationTex=None, material=None, putOnlyTexCoords=None, srgbTexturing=None, materials=None, groups=None, blendTranslucency=None, premultipliedAlpha=None, writeZTransparent=None, alphaBlend=None, depthTest=None, cullFace=None, lineWidth=None, pointSize=None, lineSmooth=None, pointSmooth=None, isEnabled=None, primitiveType=None, blendEquation=None, sfactor=None, dfactor=None, **kwargs):
    """
    Visual model for OpenGL display using Glew extensions


    :param name: object name  Default value: OglShaderVisualModel

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position: Vertices coordinates  Default value: []

    :param restPosition: Vertices rest coordinates  Default value: []

    :param normal: Normals of the model  Default value: []

    :param initRestPositions: True if rest positions must be initialized with initial positions  Default value: 0

    :param useNormals: True if normal smoothing groups should be read from file  Default value: 1

    :param updateNormals: True if normals should be updated at each iteration  Default value: 1

    :param computeTangents: True if tangents should be computed at startup  Default value: 0

    :param updateTangents: True if tangents should be updated at each iteration  Default value: 1

    :param handleDynamicTopology: True if topological changes should be handled  Default value: 1

    :param fixMergedUVSeams: True if UV seams should be handled even when duplicate UVs are merged  Default value: 1

    :param keepLines: keep and draw lines (false by default)  Default value: 0

    :param vertices: vertices of the model (only if vertices have multiple normals/texcoords, otherwise positions are used)  Default value: []

    :param texcoords: coordinates of the texture  Default value: []

    :param tangents: tangents for normal mapping  Default value: []

    :param bitangents: tangents for normal mapping  Default value: []

    :param edges: edges of the model  Default value: []

    :param triangles: triangles of the model  Default value: []

    :param quads: quads of the model  Default value: []

    :param vertPosIdx: If vertices have multiple normals/texcoords stores vertices position indices  Default value: []

    :param vertNormIdx: If vertices have multiple normals/texcoords stores vertices normal indices  Default value: []

    :param filename:  Path to an ogl model  Default value: 

    :param texturename: Name of the Texture  Default value: 

    :param translation: Initial Translation of the object  Default value: [[0.0, 0.0, 0.0]]

    :param rotation: Initial Rotation of the object  Default value: [[0.0, 0.0, 0.0]]

    :param scale3d: Initial Scale of the object  Default value: [[1.0, 1.0, 1.0]]

    :param scaleTex: Scale of the texture  Default value: [[1.0, 1.0]]

    :param translationTex: Translation of the texture  Default value: [[0.0, 0.0]]

    :param material: Material  Default value: Default Diffuse 1 0.75 0.75 0.75 1 Ambient 1 0.2 0.2 0.2 1 Specular 0 1 1 1 1 Emissive 0 0 0 0 0 Shininess 0 45 

    :param putOnlyTexCoords: Give Texture Coordinates without the texture binding  Default value: 0

    :param srgbTexturing: When sRGB rendering is enabled, is the texture in sRGB colorspace?  Default value: 0

    :param materials: List of materials  Default value: 

    :param groups: Groups of triangles and quads using a given material  Default value: 

    :param blendTranslucency: Blend transparent parts  Default value: 1

    :param premultipliedAlpha: is alpha premultiplied ?  Default value: 0

    :param writeZTransparent: Write into Z Buffer for Transparent Object  Default value: 0

    :param alphaBlend: Enable alpha blending  Default value: 0

    :param depthTest: Enable depth testing  Default value: 1

    :param cullFace: Face culling (0 = no culling, 1 = cull back faces, 2 = cull front faces)  Default value: 0

    :param lineWidth: Line width (set if != 1, only for lines rendering)  Default value: 1.0

    :param pointSize: Point size (set if != 1, only for points rendering)  Default value: 1.0

    :param lineSmooth: Enable smooth line rendering  Default value: 0

    :param pointSmooth: Enable smooth point rendering  Default value: 0

    :param isEnabled: Activate/deactive the component.  Default value: 1

    :param primitiveType: Select types of primitives to send (necessary for some shader types such as geometry or tesselation)  Default value: DEFAULT

    :param blendEquation: if alpha blending is enabled this specifies how source and destination colors are combined  Default value: GL_FUNC_ADD

    :param sfactor: if alpha blending is enabled this specifies how the red, green, blue, and alpha source blending factors are computed  Default value: GL_SRC_ALPHA

    :param dfactor: if alpha blending is enabled this specifies how the red, green, blue, and alpha destination blending factors are computed  Default value: GL_ONE_MINUS_SRC_ALPHA


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, restPosition=restPosition, normal=normal, initRestPositions=initRestPositions, useNormals=useNormals, updateNormals=updateNormals, computeTangents=computeTangents, updateTangents=updateTangents, handleDynamicTopology=handleDynamicTopology, fixMergedUVSeams=fixMergedUVSeams, keepLines=keepLines, vertices=vertices, texcoords=texcoords, tangents=tangents, bitangents=bitangents, edges=edges, triangles=triangles, quads=quads, vertPosIdx=vertPosIdx, vertNormIdx=vertNormIdx, filename=filename, texturename=texturename, translation=translation, rotation=rotation, scale3d=scale3d, scaleTex=scaleTex, translationTex=translationTex, material=material, putOnlyTexCoords=putOnlyTexCoords, srgbTexturing=srgbTexturing, materials=materials, groups=groups, blendTranslucency=blendTranslucency, premultipliedAlpha=premultipliedAlpha, writeZTransparent=writeZTransparent, alphaBlend=alphaBlend, depthTest=depthTest, cullFace=cullFace, lineWidth=lineWidth, pointSize=pointSize, lineSmooth=lineSmooth, pointSmooth=pointSmooth, isEnabled=isEnabled, primitiveType=primitiveType, blendEquation=blendEquation, sfactor=sfactor, dfactor=dfactor)
    return "OglShaderVisualModel", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BaseConstraintForceField

.. autofunction:: BaseConstraintForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BaseConstraintForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, useForce=None, normal=None, kn=None, temporaryForce=None, temporaryTimes=None, kp=None, heartPeriod=None, Zone=None, tagSolver=None, loadername=None, **kwargs):
    """
    Spring Constraint on the base for heart simulation


    :param name: object name  Default value: BaseConstraintForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param useForce: if a force has to be added  Default value: 0

    :param normal: vec3d of the normal direction of the spring  Default value: [[0.0, 0.0, 0.0]]

    :param kn: stiffness in the normal direction  Default value: 0.0

    :param temporaryForce: temporaryForce  Default value: 0

    :param temporaryTimes: vec3d of the 3 times of force  Default value: [[0.0, 0.0, 0.0]]

    :param kp: stiffness in the parallel direction  Default value: 0.0

    :param heartPeriod: heart period  Default value: 0.0

    :param Zone: List of tetra on a base  Default value: []

    :param tagSolver: Tag of the Solver Object  Default value: solver

    :param loadername: loader name  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, useForce=useForce, normal=normal, kn=kn, temporaryForce=temporaryForce, temporaryTimes=temporaryTimes, kp=kp, heartPeriod=heartPeriod, Zone=Zone, tagSolver=tagSolver, loadername=loadername)
    return "BaseConstraintForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TriangularBiquadraticSpringsForceField

.. autofunction:: TriangularBiquadraticSpringsForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TriangularBiquadraticSpringsForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, triangleInfo=None, edgeInfo=None, initialPoints=None, poissonRatio=None, youngModulus=None, dampingRatio=None, useAngularSprings=None, compressible=None, matrixRegularization=None, **kwargs):
    """
    Biquadratic Springs on a Triangular Mesh


    :param name: object name  Default value: TriangularBiquadraticSpringsForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param triangleInfo: Internal triangle data  Default value: 

    :param edgeInfo: Internal edge data  Default value: 

    :param initialPoints: Initial Position  Default value: []

    :param poissonRatio: Poisson ratio in Hooke's law  Default value: 0.3

    :param youngModulus: Young modulus in Hooke's law  Default value: 1000.0

    :param dampingRatio: Ratio damping/stiffness  Default value: 0.0

    :param useAngularSprings: If Angular Springs should be used or not  Default value: 1

    :param compressible: If additional energy penalizing compressibility should be used  Default value: 1

    :param matrixRegularization: Regularization of the Stiffnes Matrix (between 0 and 1)  Default value: 0.4


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, triangleInfo=triangleInfo, edgeInfo=edgeInfo, initialPoints=initialPoints, poissonRatio=poissonRatio, youngModulus=youngModulus, dampingRatio=dampingRatio, useAngularSprings=useAngularSprings, compressible=compressible, matrixRegularization=matrixRegularization)
    return "TriangularBiquadraticSpringsForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component HexahedronSetGeometryAlgorithms

.. autofunction:: HexahedronSetGeometryAlgorithms

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def HexahedronSetGeometryAlgorithms(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, showIndicesScale=None, showPointIndices=None, tagMechanics=None, showEdgeIndices=None, drawEdges=None, drawColorEdges=None, showQuadIndices=None, drawQuads=None, drawColorQuads=None, showHexaIndices=None, drawHexahedra=None, drawScaleHexahedra=None, drawColorHexahedra=None, **kwargs):
    """
    Hexahedron set geometry algorithms


    :param name: object name  Default value: HexahedronSetGeometryAlgorithms

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param showIndicesScale: Debug : scale for view topology indices  Default value: 0.019999999553

    :param showPointIndices: Debug : view Point indices  Default value: 0

    :param tagMechanics: Tag of the Mechanical Object  Default value: 

    :param showEdgeIndices: Debug : view Edge indices.  Default value: 0

    :param drawEdges: if true, draw the edges in the topology.  Default value: 0

    :param drawColorEdges: RGB code color used to draw edges.  Default value: [[0.4000000059604645, 1.0, 0.30000001192092896, 1.0]]

    :param showQuadIndices: Debug : view Quad indices  Default value: 0

    :param drawQuads: if true, draw the quads in the topology  Default value: 0

    :param drawColorQuads: RGB code color used to draw quads.  Default value: [[0.0, 0.4000000059604645, 0.4000000059604645, 1.0]]

    :param showHexaIndices: Debug : view Hexa indices  Default value: 0

    :param drawHexahedra: if true, draw the Hexahedron in the topology  Default value: 0

    :param drawScaleHexahedra: Scale of the hexahedra (between 0 and 1; if <1.0, it produces gaps between the hexahedra)  Default value: 1.0

    :param drawColorHexahedra: RGB code color used to draw hexahedra.  Default value: [[1.0, 0.5, 0.0, 1.0]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, showIndicesScale=showIndicesScale, showPointIndices=showPointIndices, tagMechanics=tagMechanics, showEdgeIndices=showEdgeIndices, drawEdges=drawEdges, drawColorEdges=drawColorEdges, showQuadIndices=showQuadIndices, drawQuads=drawQuads, drawColorQuads=drawColorQuads, showHexaIndices=showHexaIndices, drawHexahedra=drawHexahedra, drawScaleHexahedra=drawScaleHexahedra, drawColorHexahedra=drawColorHexahedra)
    return "HexahedronSetGeometryAlgorithms", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PressureConstraintForceField

.. autofunction:: PressureConstraintForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PressureConstraintForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, loadername=None, loaderZoneNames=None, loaderZones=None, pointZoneName=None, pointZones=None, trianglesSurf=None, tagSolver=None, atriumParam=None, aorticParam=None, Pv0=None, heartPeriod=None, file=None, Kiso=None, windkessel=None, SurfaceZone=None, useProjection=None, useVerdandi=None, DisableFirstAtriumContraction=None, ZoneType=None, graphPressure=None, graphVolume=None, graphFlow=None, volume=None, pressurePv=None, pressurePat=None, pressurePar=None, flowQ=None, displayName=None, BoundaryEdgesPath=None, BoundaryEdgesKey=None, edgeInfo=None, **kwargs):
    """
    PressureConstraint's law in Tetrahedral finite elements


    :param name: object name  Default value: PressureConstraintForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param loadername: give ATET3D or VTK  Default value: 

    :param loaderZoneNames: name of the surface zone from the loader  Default value: []

    :param loaderZones: loaderZones  Default value: []

    :param pointZoneName: list of point zone  Default value: []

    :param pointZones: list of points  Default value: []

    :param trianglesSurf: list of surface triangles  Default value: []

    :param tagSolver: Tag of the Solver Object  Default value: solver

    :param atriumParam: Kat, Pat0, Patm, alpha1, alpha2, tof, tm, tc  Default value: []

    :param aorticParam: Kar, Par0, Pve,tau=Rp*C,Rp,Zc,L  Default value: []

    :param Pv0: minimal Pressure ventricule  Default value: 1000.0

    :param heartPeriod: heart period  Default value: 0.0

    :param file: File name to register pressures  Default value: 

    :param Kiso: parameter K isovolumic  Default value: []

    :param windkessel: which model of windkessel (2,3,4)?  Default value: 0

    :param SurfaceZone: List of triangles on the surface  Default value: []

    :param useProjection: useProjection  Default value: 0

    :param useVerdandi: useVerdandi  Default value: 0

    :param DisableFirstAtriumContraction: DisableFirstAtriumContraction  Default value: 0

    :param ZoneType: Triangles or Points  Default value: 

    :param graphPressure: Pressures per iteration  Default value: 

    :param graphVolume: Volume per iteration  Default value: 

    :param graphFlow: Flow per iteration  Default value: 

    :param volume: Volume.  Default value: 0.0

    :param pressurePv: Pressure Pv  Default value: 0.0

    :param pressurePat: Pressure Pat  Default value: 0.0

    :param pressurePar: Pressure Par  Default value: 0.0

    :param flowQ: Flow Q  Default value: 0.0

    :param displayName: ONLY used for the Cardiac GUI: name displayed in the GUI  Default value: 

    :param BoundaryEdgesPath: Path to the json file containing holes as orderred list of point id pairs  Default value: 

    :param BoundaryEdgesKey: Key (LV|RV) of the ventricle to retrieve edges in json file  Default value: 

    :param edgeInfo: Data to handle topology on edges  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, loadername=loadername, loaderZoneNames=loaderZoneNames, loaderZones=loaderZones, pointZoneName=pointZoneName, pointZones=pointZones, trianglesSurf=trianglesSurf, tagSolver=tagSolver, atriumParam=atriumParam, aorticParam=aorticParam, Pv0=Pv0, heartPeriod=heartPeriod, file=file, Kiso=Kiso, windkessel=windkessel, SurfaceZone=SurfaceZone, useProjection=useProjection, useVerdandi=useVerdandi, DisableFirstAtriumContraction=DisableFirstAtriumContraction, ZoneType=ZoneType, graphPressure=graphPressure, graphVolume=graphVolume, graphFlow=graphFlow, volume=volume, pressurePv=pressurePv, pressurePat=pressurePat, pressurePar=pressurePar, flowQ=flowQ, displayName=displayName, BoundaryEdgesPath=BoundaryEdgesPath, BoundaryEdgesKey=BoundaryEdgesKey, edgeInfo=edgeInfo)
    return "PressureConstraintForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GenerateCardiacCylinder

.. autofunction:: GenerateCardiacCylinder

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GenerateCardiacCylinder(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, output_position=None, tetrahedra=None, radius=None, height=None, origin=None, resCircumferential=None, resRadial=None, resHeight=None, facetFibers=None, depolarisationTimes=None, APD=None, APD_input=None, **kwargs):
    """
    Generate a Cylindrical Tetrahedral Mesh


    :param name: object name  Default value: GenerateCardiacCylinder

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param output_position: output array of 3d points  Default value: []

    :param tetrahedra: output mesh tetrahedra  Default value: []

    :param radius: input cylinder radius  Default value: 0.2

    :param height: input cylinder height  Default value: 1.0

    :param origin: cylinder origin point  Default value: [[0.0, 0.0, 0.0]]

    :param resCircumferential: Resolution in the circumferential direction  Default value: 6

    :param resRadial: Resolution in the radial direction  Default value: 3

    :param resHeight: Resolution in the height direction  Default value: 5

    :param facetFibers: Fiber par facet of the mesh loaded.  Default value: []

    :param depolarisationTimes: depolarisationTimes at each node  Default value: []

    :param APD: APD at each node  Default value: []

    :param APD_input: Action potential duration given as input  Default value: 0.2


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, output_position=output_position, tetrahedra=tetrahedra, radius=radius, height=height, origin=origin, resCircumferential=resCircumferential, resRadial=resRadial, resHeight=resHeight, facetFibers=facetFibers, depolarisationTimes=depolarisationTimes, APD=APD, APD_input=APD_input)
    return "GenerateCardiacCylinder", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component AttachConstraint

.. autofunction:: AttachConstraint

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def AttachConstraint(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, group=None, endTime=None, indices1=None, indices2=None, twoWay=None, freeRotations=None, lastFreeRotation=None, restRotations=None, lastPos=None, lastDir=None, clamp=None, minDistance=None, positionFactor=None, velocityFactor=None, responseFactor=None, constraintFactor=None, **kwargs):
    """
    Attach given pair of particles, projecting the positions of the second particles to the first ones


    :param name: object name  Default value: AttachConstraint

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param group: ID of the group containing this constraint. This ID is used to specify which constraints are solved by which solver, by specifying in each solver which groups of constraints it should handle.  Default value: 0

    :param endTime: The constraint stops acting after the given value.
Use a negative value for infinite constraints  Default value: -1.0

    :param indices1: Indices of the source points on the first model  Default value: []

    :param indices2: Indices of the fixed points on the second model  Default value: []

    :param twoWay: true if forces should be projected back from model2 to model1  Default value: 0

    :param freeRotations: true to keep rotations free (only used for Rigid DOFs)  Default value: 0

    :param lastFreeRotation: true to keep rotation of the last attached point free (only used for Rigid DOFs)  Default value: 0

    :param restRotations: true to use rest rotations local offsets (only used for Rigid DOFs)  Default value: 0

    :param lastPos: position at which the attach constraint should become inactive  Default value: [[0.0, 0.0, 0.0]]

    :param lastDir: direction from lastPos at which the attach coustraint should become inactive  Default value: [[0.0, 0.0, 0.0]]

    :param clamp: true to clamp particles at lastPos instead of freeing them.  Default value: 0

    :param minDistance: the constraint become inactive if the distance between the points attached is bigger than minDistance.  Default value: -1.0

    :param positionFactor: IN: Factor applied to projection of position  Default value: 1.0

    :param velocityFactor: IN: Factor applied to projection of velocity  Default value: 1.0

    :param responseFactor: IN: Factor applied to projection of force/acceleration  Default value: 1.0

    :param constraintFactor: Constraint factor per pair of points constrained. 0 -> the constraint is released. 1 -> the constraint is fully constrained  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, group=group, endTime=endTime, indices1=indices1, indices2=indices2, twoWay=twoWay, freeRotations=freeRotations, lastFreeRotation=lastFreeRotation, restRotations=restRotations, lastPos=lastPos, lastDir=lastDir, clamp=clamp, minDistance=minDistance, positionFactor=positionFactor, velocityFactor=velocityFactor, responseFactor=responseFactor, constraintFactor=constraintFactor)
    return "AttachConstraint", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TetrahedronVolumeMapping

.. autofunction:: TetrahedronVolumeMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TetrahedronVolumeMapping(self, **kwargs):
    """
    Map deformation gradients to the invariants of the right Cauchy Green deformation tensor: I1, I2 and J



    """
    params = dict()
    return "TetrahedronVolumeMapping", params
